@@ -15,6 +15,7 @@ class Config:
         customer: str,
         src_lang: str,
         tgt_lang: str,
+        config_dict: Dict = None,
         flavor: Optional[str] = None,
         version=1,
         processors: Dict = None,
@@ -24,6 +25,8 @@ class Config:
         translation_model: Dict = None,
     ):
         self.data_dir = project_dir.joinpath(Config.DATA_DIR)
+        if config_dict is not None:
+            self.config_dict = config_dict
 
     # Takes the path to the config and returns a Config object
     @staticmethod
@@ -36,6 +39,7 @@ class Config:
             data["customer"],
             data["src_lang"],
             data["tgt_lang"],
+            data,
             data["flavor"],
             data["version"],
             data["processors"],
