@@ -4,6 +4,7 @@ import os
 import click
 import pathlib
 from pathos.multiprocessing import Pool
+from contextlib import closing
 from pangeamt_nlp.tokenizer.tokenizer_factory import TokenizerFactory
 from pangeamt_tea.project.workflow.stage.base_stage import BaseStage
 from pangeamt_tea.project.workflow.stage.stage_factory import StageFactory
@@ -194,7 +195,7 @@ class PrepareStage(BaseStage):
                 out_path = os.path.join(dir, file)
                 with open(in_path, "r", encoding="utf-8") as in_file:
                     with open(out_path, "w+", encoding="utf-8") as out_file:
-                        with Pool(max_workers) as pool:
+                        with closing(Pool(max_workers)) as pool:
                             with click.progressbar(
                                 pool.imap(
                                     lambda x: tokenizer.tokenize(x),
@@ -381,7 +382,7 @@ class PrepareStage(BaseStage):
                         with open(
                             out_path, "w+", encoding="utf-8"
                         ) as out_file:
-                            with Pool(max_workers) as pool:
+                            with closing(Pool(max_workers)) as pool:
                                 with click.progressbar(
                                     pool.imap(
                                         lambda x: bpe.apply(x),
